==> libreoffice_4.0.4.orig.tar.xz: libreoffice-4.0.4/dbaccess/source/ui/querydesign/QTableWindowData.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "QTableWindowData.hxx"
#include <tools/debug.hxx>


using namespace dbaui;
using namespace ::com::sun::star::io;
using namespace ::com::sun::star::uno;

DBG_NAME(OQueryTableWindowData)
//==================================================================
// class OQueryTableWindowData
//==================================================================
//------------------------------------------------------------------------------
OQueryTableWindowData::OQueryTableWindowData(const ::rtl::OUString& _rComposedName, const ::rtl::OUString& rTableName, const ::rtl::OUString& rTableAlias )
    :OTableWindowData(NULL,_rComposedName, rTableName, rTableAlias)
{
    DBG_CTOR(OQueryTableWindowData,NULL);
}

//------------------------------------------------------------------------------
OQueryTableWindowData::~OQueryTableWindowData()
{
    DBG_DTOR(OQueryTableWindowData,NULL);
}
// -----------------------------------------------------------------------------




/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-4.1.4.2.tar.xz: libreoffice-4.1.4.2/dbaccess/source/ui/querydesign/QTableWindowData.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "QTableWindowData.hxx"
#include <tools/debug.hxx>


using namespace dbaui;
using namespace ::com::sun::star::io;
using namespace ::com::sun::star::uno;

DBG_NAME(OQueryTableWindowData)
//==================================================================
// class OQueryTableWindowData
//==================================================================
//------------------------------------------------------------------------------
OQueryTableWindowData::OQueryTableWindowData(const OUString& _rComposedName, const OUString& rTableName, const OUString& rTableAlias )
    :OTableWindowData(NULL,_rComposedName, rTableName, rTableAlias)
{
    DBG_CTOR(OQueryTableWindowData,NULL);
}

//------------------------------------------------------------------------------
OQueryTableWindowData::~OQueryTableWindowData()
{
    DBG_DTOR(OQueryTableWindowData,NULL);
}
// -----------------------------------------------------------------------------




/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
